@@ -58,7 +58,10 @@ def jjm_login(obj: JenkinsJobManager):
     click.secho("Configuring login info for:", fg="green")
     click.secho(f"\t{jurl}", fg="white")
 
-    click.secho(f"\nEnter username, go to {jurl}/whoAmI/ if unsure.")
+    click.secho(
+        f"\nEnter username, If unsure go to {jurl}/whoAmI/"
+        f" (if this says anonymous, you need to login first)"
+    )
     username = click.prompt("username", type=str)
 
     click.secho(
@@ -131,15 +134,16 @@ def handle_plan_report(obj: JenkinsJobManager, use_pager=True) -> bool:
 
 
 @jjm.command(name="plan")
+@click.option("--skip-pager", is_flag=True)
 @click.pass_obj
-def jjm_plan(obj: JenkinsJobManager):
+def jjm_plan(obj: JenkinsJobManager, skip_pager: bool):
     """check for changes"""
     check_auth(obj)
     obj.gather()
     handle_validation_errors(obj)
-    changes = handle_plan_report(obj, use_pager=True)
+    changes = handle_plan_report(obj, use_pager=not skip_pager)
     if changes:
-        click.exceptions.Exit(2)
+        raise click.exceptions.Exit(2)
 
 
 @jjm.command(name="apply")
